'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Endpoint = require('../Endpoint.js');
var Exception = require('../Exception.js');
var Client = require('../Client.js');
var Result = require('./Result.js');

class Results extends Endpoint['default'] {
    /**
     *
     * @param {Client} client
     * @param {string} testId
     */
    constructor(client, testId) {
        super(client);

        this.testId = testId;
    }

    /**
     *
     * @param {string} id
     * @return {Promise<Result>}
     */
    async get(id) {
        const data = await this.client.request(`tests/${this.testId}/results/${id}`, Client['default'].METHOD.GET);
        if (data === undefined) {
            throw new Exception['default'](`Loader.io result ${id} can not be found.`);
        }

        return new Result['default'](data);
    }

    /**
     * @return {Promise<Result[]>}
     */
    async list() {
        const data = await this.client.request(`tests/${this.testId}/results`, Client['default'].METHOD.GET);
        if (data === undefined) {
            return [];
        }

        return data.map((entry) => new Result['default'](entry));
    }
}

module.exports = exports = Results;

exports.default = Results;
